@@ -1,11 +1,10 @@
-"""
-Wrapper classes around multidimensional numpy matrices
+"""Wrapper classes around multidimensional numpy matrices
 for (dis)aggregation of data.
 """
 
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-__version__ = "0.1.4"
+__version__ = "0.2.0"
 __title__ = "Data Disaggregation"
 __author__ = "Christian Winger"
 __email__ = "c.winger@oeko.de"
@@ -15,6 +14,8 @@ __url__ = "https://github.com/wingechr/data-disaggregation"
 try:
     from .classes import (
         Dimension,
+        DimensionLevel,
+        Domain,
         ExtensiveScalar,
         ExtensiveVariable,
         IntensiveScalar,
@@ -28,6 +29,8 @@ except ImportError:
 
 __all__ = [
     "Dimension",
+    "DimensionLevel",
+    "Domain",
     "ExtensiveScalar",
     "ExtensiveVariable",
     "IntensiveScalar",
